@@ -208,7 +208,7 @@ main (gint argc, gchar **argv)
 	ev_stock_icons_init ();
 
 	g_set_application_name (_("GNOME Document Previewer"));
-	gtk_window_set_default_icon_name ("evince");
+	gtk_window_set_default_icon_name ("org.gnome.Evince");
 
         application = gtk_application_new (NULL,
                                            G_APPLICATION_NON_UNIQUE |
